.. BeForData documentation master file, created by
   sphinx-quickstart on Thu Dec  5 15:56:33 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

BeForData's documentation!
==========================


Data structure for handling behavioural force data

|GitHub license| |PyPI|

GitHub: https://github.com/lindemann09/befordata


Install via pip
---------------

::

   pip install befordata


\(c\) Oliver Lindemann

.. |GitHub license| image:: https://img.shields.io/github/license/lindemann09/befordata
   :target: https://github.com/lindemann09/befordata/blob/master/LICENSE
.. |PyPI| image:: https://img.shields.io/pypi/v/befordata?style=flat
   :target: https://pypi.org/project/befordata/



.. toctree::
   :maxdepth: 2
   :caption: Contents:

   usage
   api


